@@ -991,7 +991,8 @@ class SaleLine(ModelSQL, ModelView):
             'required': Eval('type') == 'line',
             'readonly': ~Eval('_parent_sale', {}),
             }, on_change=['product', 'quantity', 'unit',
-            '_parent_sale.currency', '_parent_sale.party'],
+            '_parent_sale.currency', '_parent_sale.party',
+            '_parent_sale.sale_date'],
         depends=['type', 'unit_digits'])
     unit = fields.Many2One('product.uom', 'Unit',
             states={
@@ -1016,7 +1017,8 @@ class SaleLine(ModelSQL, ModelView):
             'readonly': ~Eval('_parent_sale', {}),
             },
         on_change=['product', 'unit', 'quantity', 'description',
-            '_parent_sale.party', '_parent_sale.currency'],
+            '_parent_sale.party', '_parent_sale.currency',
+            '_parent_sale.sale_date'],
         context={
             'locations': If(Bool(Eval('_parent_sale', {}).get('warehouse')),
                 [Eval('_parent_sale', {}).get('warehouse', 0)], []),
@@ -2081,7 +2083,7 @@ class HandleInvoiceException(Wizard):
             if invoice.state == 'cancel' and invoice.id not in skip_ids:
                 invoices.append(invoice.id)
         return {
-            'to_recreate': invoices,
+            'recreate_invoices': invoices,
             'domain_invoices': invoices,
             }
 
